| Title: | An RKWard plugin package for transforming dates and times to POSIX R format. |
|---|---|
| Description: | An RKWard plugin package for transforming dates and times to POSIX R format. |
| Authors: | Alfonso Cano Robles |
| Maintainer: | Alfonso Cano Robles <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.3 |
| Built: | 2026-05-18 10:08:06 UTC |
| Source: | https://github.com/AlfCano/rk.dates |